/*	---------------------------------------------------------------
 * Script:	page-manager.js
 * Role:		Utility for all pages:
 * 	a)	Setting default configuartion if storage is not available
 * 	b)	Setting top and bottom margins
 * 	c)	Setting the required theme
 * 	d)	Providing utility functions
 * Version:	1.0.4
 * Author:	Neil Thomas
 * Edited:	23 Mar 2023
 * Checked:
 * ---------------------------------------------------------------*/

/*	Global settings
 *	These values are used if local string storage is NOT available
 *	They can be edited directly but please note that theme names
 * use the filename without the prefix 'thm'.
 *	--------------------------------------------------------------- */

let CMXConfig = {'Theme': 'DefaultBlue',
					  'darkMode': false,
					  'StaticHead': true,
					  'StaticFoot': true,
					  'PaddingTop': '10px',
					  'PaddingBottom': '120px'
					 }


$( function() {
	getStoredConfig();
	setTheme();
	getMenus();
	getCMXVersion();
	getLocation();
});

let getStoredConfig = function() {
	if( typeof( Storage ) !== "undefined" ) {
		console.log("Storage available");
		var storedConfig = JSON.parse(localStorage.getItem( "CMXai2" ) );
		//console.log("Stored config: " + JSON.stringify( storedConfig ) );
		if( storedConfig === null ) {
			storeConfig();
		} else {
			CMXConfig = storedConfig;
			//console.log("CMX Config: " + JSON.stringify( CMXConfig ));
		}
	} else {
		console.log( "Storage not available" );
	}
};

let storeConfig = function() {
	console.log( "Storing default settings" );
	localStorage.setItem( "CMXai2", JSON.stringify( CMXConfig ) );
};

let setTheme = function() {
	var mode = "";
	if( CMXConfig.darkMode ) { var mode = '-Dark'; }
	$('#ai-theme').attr('href', 'css/thm' + CMXConfig.Theme + mode + '.css' );
};

let getMenus = function() {
	//	Main menu
	$.ajax( { 
		url: 'menuMain.html',
		dataType: 'text',
		success: function( result ) {
			$('#menuMain').html( result );
			//console.log( "Main menu loaded" );
		},
		error: function() {
			console.log( "Failed to load main menu" );
		},
		complete: function() {
			setupPage();
		}
	});
	//	Mobile menu
	$.ajax( {
		url: 'menuMobile.html',
		dataType: 'text',
		success: function(result){
			$('#menuMobile').html( result );
			//console.log( "Mobile menu loaded" );
		},
		error: function() {
			console.log( "Failed to load mobile menu" );
		},
		complete: function() {
			setupPage();
		}
	});
};

let setupPage = function() {
	//	Adjust page margins and padding
	var elHeight;
	if( CMXConfig.StaticHead ) {
		$('#page-head').addClass( 'w3-top' );
		elHeight = $('#page-head').outerHeight( false );
		$('#content').css('margin-top', elHeight + 'px');
	} else {
		$('#page-head').removeClass('w3-top');
		$('#content').css('margin-top', '0px');
	}
	if( CMXConfig.StaticFoot && ($(window).width() > 600) ) {
		$('#page-tail').addClass('w3-bottom');
		elHeight = $('#page-tail').outerHeight( true );
		$('#content').css('margin-bottom', elHeight + 'px' );
	} else {
		$('#page-tail').removeClass('w3-bottom');
		$('#content').css('margin-bottom', '0px');
	}
	//	Set padding
	$('#content').css('padding-top', CMXConfig.PaddingTop);
	$('#content').css('padding-bottom', CMXConfig.PaddingBottom);
	//	Set Content height
	elHeight = $('#page-head').outerHeight( true ) + $('#page-tail').outerHeight( true ); 
	var contentHeight = $(window).height() - elHeight + 'px';
	//console.log(" Content height: " + contentHeight ) 
	$('#content').css('min-height', contentHeight );
	 var davisPanel = localStorage.getItem('CMXDavis');
	 if( davisPanel === 'Hide' ) {
		$('#DavisPanel').addClass('w3-hide');
		$('#DavisSet').text('Show Davis Info');
	}
};

let showModal = function(modal){
	$('#' + modal).toggleClass('w3-show', 'w3-hide');
	if( $('#' + modal).hasClass('w3-show') ) {
		var child = $('#' + modal).children('.w3-modal-content');
		var mHeight = $(child).outerHeight( true );
		$( child ).css('margin-top', ($(window).outerHeight() - mHeight) / 3 +'px');
	}
};

window.onresize = function() {
	setupPage();
}

let getCMXVersion = function() {
	$.ajax({
		url: '/api/settings/version.json',
		success: function( result ) {
			$('[data-cmxdata=Version]').html( result.Version );
			$('[data-cmxdata=Build]').html( result.Build ); 
		},
		error: function( xhr ) {
			console.log( "Failed to load version data: " + xhr.status );
			$('[data-cmxdata=Version]').html("Not known");
		}
	})
};


let getLocation = function() {
	//	Gets the weather station Lat, Long & altitude
	
	$.ajax({
		url: '/api/tags/process.txt',
        dataType: 'json',
        type: 'POST',
        data: '{"Latitude": "<#latitude>", "Longitude": "<#longitude>", "Altitude": "<#altitude>"}'
    })
    .done( function (result) {
		$('[data-cmxdata=latitude]').html( result.Latitude);
		$('[data-cmxdata=longitude]').html( result.Longitude );
		$('[data-cmxdata=altitude]').html( result.Altitude );
	})
	
	.fail( function() {
		console.log("Failed to get data");
	})
	/* */
};


let toggleTabs = function( elm, cls ) {
	//	Hides or reveals single panel tabs
	$("." + cls).addClass("w3-hide");
	$("#" + elm).removeClass("w3-hide");
};

let toggleMenu = function(menuId) {
	//	Assumes currently hidden
	console.log("Toggling menu: " + menuId);
	$('#' + menuId).toggleClass( 'w3-show', 'w3-hide' );
};

let toggleArea = function(area) {
	$('#' + area + 'Panel').toggleClass("w3-hide", "w3-show");
	var btnText = $('#' + area + 'Set').text();
	if( btnText.slice(0,4) == "Show") {
		$('#' + area + 'Set').text(btnText.replace("Show","Hide"));
		if( area == 'Davis' ) {
			localStorage.setItem('CMXDavis', 'Show');
		}
	} else {
		$('#' + area + 'Set').text(btnText.replace("Hide","Show"));
		if( area == 'Davis' ) {
			localStorage.setItem( 'CMXDavis', 'Hide' );
		}
	}
		
};

/*	Uncomment the line below to clear any stored configuration. */
//storeConfig();

